==> jc-1.4.0.tar.gz: soot/jimple/Constant.h <==
// public abstract class soot.jimple.Constant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_Constant_H_
#define _JC_soot_jimple_Constant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_Constant$sub_refs	_jc_soot_jimple_Constant$sub_refs;
typedef struct _jc_soot_jimple_Constant$sub_nonrefs	_jc_soot_jimple_Constant$sub_nonrefs;
typedef struct _jc_soot_jimple_Constant$refs	_jc_soot_jimple_Constant$refs;
typedef struct _jc_soot_jimple_Constant$nonrefs	_jc_soot_jimple_Constant$nonrefs;
typedef struct _jc_soot_jimple_Constant$object	_jc_soot_jimple_Constant$object;

typedef const struct _jc_soot_jimple_Constant$vmethods	_jc_soot_jimple_Constant$vmethods;
typedef const struct _jc_soot_jimple_Constant$vtable	_jc_soot_jimple_Constant$vtable;
typedef const struct _jc_soot_jimple_Constant$vtype	_jc_soot_jimple_Constant$vtype;

// Constructors
extern void _jc_soot_jimple_Constant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_Constant$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_Constant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_Constant$object *);
extern void _jc_soot_jimple_Constant$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
extern jint _jc_soot_jimple_Constant$method$equivHashCode$a61e38ee84d179c1(_jc_env *, struct _jc_soot_jimple_Constant$object *);
extern jboolean _jc_soot_jimple_Constant$method$equivTo$4576338963d2dec1(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_jimple_Constant$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_Constant$object *);
extern void _jc_soot_jimple_Constant$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_Constant$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_Constant$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_Constant$method_info$equivHashCode$a61e38ee84d179c1;
extern _jc_method _jc_soot_jimple_Constant$method_info$equivTo$4576338963d2dec1;
extern _jc_method _jc_soot_jimple_Constant$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_jimple_Constant$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_Constant$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_Constant$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
	jint	(*equivHashCode$a61e38ee84d179c1)(_jc_env *, struct _jc_soot_jimple_Constant$object *);
	jboolean	(*equivTo$4576338963d2dec1)(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_Constant$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_Constant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
};

// Vtype
struct _jc_soot_jimple_Constant$vtype {
	_jc_type			type;
	_jc_soot_jimple_Constant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_Constant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_Constant$refs {
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_Constant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_Constant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
};

// Object instance structure
struct _jc_soot_jimple_Constant$object {
	_jc_soot_jimple_Constant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_Constant$vtype	*vtype;
	_jc_soot_jimple_Constant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_Constant$vtype _jc_soot_jimple_Constant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_Constant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_Constant$class_object;

#endif	/* _JC_soot_jimple_Constant_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/Constant.h <==
// public abstract class soot.jimple.Constant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_Constant_H_
#define _JC_soot_jimple_Constant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_Constant$sub_refs	_jc_soot_jimple_Constant$sub_refs;
typedef struct _jc_soot_jimple_Constant$sub_nonrefs	_jc_soot_jimple_Constant$sub_nonrefs;
typedef struct _jc_soot_jimple_Constant$refs	_jc_soot_jimple_Constant$refs;
typedef struct _jc_soot_jimple_Constant$nonrefs	_jc_soot_jimple_Constant$nonrefs;
typedef struct _jc_soot_jimple_Constant$object	_jc_soot_jimple_Constant$object;

typedef const struct _jc_soot_jimple_Constant$vmethods	_jc_soot_jimple_Constant$vmethods;
typedef const struct _jc_soot_jimple_Constant$vtable	_jc_soot_jimple_Constant$vtable;
typedef const struct _jc_soot_jimple_Constant$vtype	_jc_soot_jimple_Constant$vtype;

// Constructors
extern void _jc_soot_jimple_Constant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_Constant$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_Constant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_Constant$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_Constant$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_Constant$method$equivHashCode$a61e38ee84d179c1(_jc_env *, struct _jc_soot_jimple_Constant$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_Constant$method$equivTo$4576338963d2dec1(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_Constant$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_Constant$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_Constant$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_Constant$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_Constant$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_Constant$method_info$equivHashCode$a61e38ee84d179c1;
extern _jc_method _jc_soot_jimple_Constant$method_info$equivTo$4576338963d2dec1;
extern _jc_method _jc_soot_jimple_Constant$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_jimple_Constant$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_Constant$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_Constant$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jint	(*equivHashCode$a61e38ee84d179c1)(_jc_env *, struct _jc_soot_jimple_Constant$object *) _JC_JCNI_ATTR;
	jboolean	(*equivTo$4576338963d2dec1)(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_Constant$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_Constant$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_Constant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
};

// Vtype
struct _jc_soot_jimple_Constant$vtype {
	_jc_type			type;
	_jc_soot_jimple_Constant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_Constant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_Constant$refs {
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_Constant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_Constant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
};

// Object instance structure
struct _jc_soot_jimple_Constant$object {
	_jc_soot_jimple_Constant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_Constant$vtype	*vtype;
	_jc_soot_jimple_Constant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_Constant$vtype _jc_soot_jimple_Constant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_Constant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_Constant$class_object;

#endif	/* _JC_soot_jimple_Constant_H_ */
